@@ -57,6 +57,41 @@ OUTER_CONFIGURATIONS_SCHEMA = {
     "description": "Instance group application configurations."
 }
 
+ONDEMAND_CAPACITY_RESERVATION_OPTIONS_SCHEMA = {
+    "type": "object",
+    "properties" : {
+        "UsageStrategy": {
+            "type": "string",
+            "description": "The strategy of whether to use available capacity reservations to fulfill On-Demand capacity.",
+            "enum": ["use-capacity-reservations-first"]
+        },
+        "CapacityReservationPreference": {
+            "type": "string",
+            "description": "The preference of the capacity reservation of the instance.",
+            "enum": [
+                "open",
+                "none"
+            ]
+        },
+        "CapacityReservationResourceGroupArn": {
+            "type": "string",
+            "description": "The ARN of the capacity reservation resource group in which to run the instance."
+        }
+    }
+}
+
+SPOT_ALLOCATION_STRATEGY_SCHEMA = {
+    "type": "string",
+    "description": "The strategy to use to launch Spot instance fleets.",
+    "enum": ["capacity-optimized", "price-capacity-optimized", "lowest-price", "diversified", "capacity-optimized-prioritized"]
+}
+
+ONDEMAND_ALLOCATION_STRATEGY_SCHEMA = {
+    "type": "string",
+    "description": "The strategy to use to launch On-Demand instance fleets.",
+    "enum": ["lowest-price", "prioritized"]
+}
+
 INSTANCE_GROUPS_SCHEMA = {
     "type": "array",
     "items": {
@@ -128,6 +163,10 @@ INSTANCE_GROUPS_SCHEMA = {
                                         "Iops": {
                                             "type": "integer",
                                             "description": "The IOPS of the EBS volume that is attached to all the instances in the instance group.",
+                                        },
+                                        "Throughput": {
+                                            "type": "integer",
+                                            "description": "The throughput of the EBS volume that is attached to all the instances in the instance group.",
                                         }
                                     }
                                 },
@@ -339,6 +378,11 @@ INSTANCE_FLEETS_SCHEMA = {
                             "type": "string",
                             "description": "The AMI ID of a custom AMI to use when Amazon EMR provisions EC2 instances."
                         },
+                        "Priority": {
+                            "type": "double",
+                            "description": "The priority at which Amazon EMR launches the EC2 instances with this instance type. "
+                                "Priority starts at 0, which is the highest priority. Amazon EMR considers the highest priority first."
+                        },
                         "EbsConfiguration": {
                             "type": "object",
                             "description": "EBS configuration that is associated with the instance group.",
@@ -374,6 +418,11 @@ INSTANCE_FLEETS_SCHEMA = {
                                                         "type": "integer",
                                                         "description": "The IOPS of the EBS volume that is attached to "
                                                             "all the instances in the instance group.",
+                                                    },
+                                                    "Throughput": {
+                                                         "type": "integer",
+                                                         "description": "The throughput of the EBS volume that is attached to "
+                                                             "all the instances in the instance group.",
                                                     }
                                                 }
                                             },
@@ -397,33 +446,8 @@ INSTANCE_FLEETS_SCHEMA = {
                     "OnDemandSpecification": {
                         "type": "object",
                         "properties": {
-                            "AllocationStrategy": {
-                                "type": "string",
-                                "description": "The strategy to use in launching On-Demand instance fleets.",
-                                "enum": ["lowest-price"]
-                            },
-                            "CapacityReservationOptions": {
-                                "type": "object",
-                                "properties" : {
-                                    "UsageStrategy": {
-                                        "type": "string",
-                                        "description": "The strategy of whether to use unused Capacity Reservations for fulfilling On-Demand capacity.",
-                                        "enum": ["use-capacity-reservations-first"]
-                                    },
-                                    "CapacityReservationPreference": {
-                                        "type": "string",
-                                        "description": "The preference of the instance's Capacity Reservation.",
-                                        "enum": [
-                                            "open",
-                                            "none"
-                                        ]
-                                    },
-                                    "CapacityReservationResourceGroupArn": {
-                                        "type": "string",
-                                        "description": "The ARN of the Capacity Reservation resource group in which to run the instance."
-                                    }
-                                }
-                            }
+                            "AllocationStrategy": ONDEMAND_ALLOCATION_STRATEGY_SCHEMA,
+                            "CapacityReservationOptions": ONDEMAND_CAPACITY_RESERVATION_OPTIONS_SCHEMA
                         }
                     },
                     "SpotSpecification": {
@@ -445,11 +469,33 @@ INSTANCE_FLEETS_SCHEMA = {
                                 "type": "integer",
                                 "description": "Block duration in minutes."
                             },
-                            "AllocationStrategy": {
-                                "type": "string",
-                                "description": "The strategy to use in launching Spot instance fleets.",
-                                "enum": ["capacity-optimized"]
-                            }
+                            "AllocationStrategy": SPOT_ALLOCATION_STRATEGY_SCHEMA
+                        }
+                    }
+                }
+            },
+            "ResizeSpecifications": {
+                "type": "object",
+                "properties": {
+                    "SpotResizeSpecification": {
+                        "type": "object",
+                        "properties": {
+                            "TimeoutDurationMinutes": {
+                                "type" : "integer",
+                                "description": "The time, in minutes, after which the resize will be stopped if requested resources are unavailable."
+                            },
+                            "AllocationStrategy": SPOT_ALLOCATION_STRATEGY_SCHEMA
+                        }
+                    },
+                    "OnDemandResizeSpecification": {
+                        "type": "object",
+                        "properties": {
+                            "TimeoutDurationMinutes": {
+                                "type" : "integer",
+                                "description": "The time, in minutes, after which the resize will be stopped if requested resources are unavailable."
+                            },
+                            "AllocationStrategy": ONDEMAND_ALLOCATION_STRATEGY_SCHEMA,
+                            "CapacityReservationOptions": ONDEMAND_CAPACITY_RESERVATION_OPTIONS_SCHEMA
                         }
                     }
                 }
@@ -823,3 +869,15 @@ PLACEMENT_GROUP_CONFIGS_SCHEMA = {
         }
     }
 }
+
+AUTO_TERMINATION_POLICY_SCHEMA = {
+    "type": "object",
+    "properties":  {
+        "IdleTimeout": {
+            "type": "long",
+            "description":
+                "Specifies the amount of idle time in seconds after which the cluster automatically terminates. "
+                "You can specify a minimum of 60 seconds and a maximum of 604800 seconds (seven days).",
+        }
+    }
+}
